@@ -24,12 +24,19 @@ class RebootClusterRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cassandra', '2019-01-01', 'RebootCluster','Cassandra')
+		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
+	def get_DataCenterId(self):
+		return self.get_query_params().get('DataCenterId')
+
+	def set_DataCenterId(self,DataCenterId):
+		self.add_query_param('DataCenterId',DataCenterId)
+
 	def get_ClusterId(self):
 		return self.get_query_params().get('ClusterId')
 
